==> umbrello-17.11.80.tar.xz: umbrello-17.11.80/lib/kdev4-php/kdevphpsupport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
Exec=blubb
Comment=PHP Language Support
Comment[ca]=Implementació del llenguatge PHP
Comment[ca@valencia]=Implementació del llenguatge PHP
Comment[cs]=Podpora jazyka PHP
Comment[de]=Sprachunterstützung für PHP
Comment[el]=Υποστήριξη γλώσσας PHP
Comment[es]=Implementación del lenguaje PHP
Comment[fr]=Prise en charge du langage PHP
Comment[gl]=Compatibilidade coa linguaxe PHP
Comment[it]=Supporto al linguaggio PHP
Comment[nb]=PHP språkstøtte
Comment[nl]=Ondersteuning van PHP-taal
Comment[pl]=Obsługa języka PHP
Comment[pt]=Suporte da Linguagem PHP
Comment[pt_BR]=Suporte à linguagem PHP
Comment[sk]=Jazyková podpora PHP
Comment[sv]=PHP-språkstöd
Comment[tr]=PHP Dili Desteği
Comment[uk]=Підтримка мови PHP
Comment[x-test]=xxPHP Language Supportxx
Comment[zh_CN]=Php 语言支持
Name=PHP Language Support
Name[ca]=Implementació del llenguatge PHP
Name[ca@valencia]=Implementació del llenguatge PHP
Name[cs]=Podpora jazyka PHP
Name[de]=Sprachunterstützung für PHP
Name[el]=Υποστήριξη γλώσσας PHP
Name[es]=Implementación del lenguaje PHP
Name[fr]=Prise en charge du langage PHP
Name[gl]=Compatibilidade coa linguaxe PHP
Name[it]=Supporto al linguaggio PHP
Name[nb]=PHP språkstøtte
Name[nl]=Ondersteuning van PHP-taal
Name[pl]=Obsługa języka PHP
Name[pt]=Suporte da Linguagem PHP
Name[pt_BR]=Suporte à linguagem PHP
Name[sk]=Jazyková podpora PHP
Name[sv]=PHP-språkstöd
Name[tr]=PHP Dili Desteği
Name[uk]=Підтримка мови PHP
Name[x-test]=xxPHP Language Supportxx
Name[zh_CN]=Php 语言支持
ServiceTypes=KDevelop/Plugin
Icon=application-x-php
X-KDE-Library=kdevphplanguagesupport
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Language=Php
X-KDevelop-Args=PHP
X-KDevelop-Interfaces=ILanguageSupport
X-KDevelop-SupportedMimeTypes=application/x-php
X-KDE-PluginInfo-Name=KDevPhpSupport
X-KDE-PluginInfo-Category=Language Support
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn

==> umbrello_17.12.3.orig.tar.xz: umbrello-17.12.3/lib/kdev4-php/kdevphpsupport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
Exec=blubb
Comment=PHP Language Support
Comment[ca]=Implementació del llenguatge PHP
Comment[ca@valencia]=Implementació del llenguatge PHP
Comment[cs]=Podpora jazyka PHP
Comment[de]=Sprachunterstützung für PHP
Comment[el]=Υποστήριξη γλώσσας PHP
Comment[en_GB]=PHP Language Support
Comment[es]=Implementación del lenguaje PHP
Comment[fr]=Prise en charge du langage PHP
Comment[gl]=Compatibilidade coa linguaxe PHP
Comment[it]=Supporto al linguaggio PHP
Comment[nb]=PHP språkstøtte
Comment[nl]=Ondersteuning van PHP-taal
Comment[pl]=Obsługa języka PHP
Comment[pt]=Suporte da Linguagem PHP
Comment[pt_BR]=Suporte à linguagem PHP
Comment[sk]=Jazyková podpora PHP
Comment[sl]=Podpora jeziku PHP
Comment[sv]=PHP-språkstöd
Comment[tr]=PHP Dili Desteği
Comment[uk]=Підтримка мови PHP
Comment[x-test]=xxPHP Language Supportxx
Comment[zh_CN]=Php 语言支持
Name=PHP Language Support
Name[ca]=Implementació del llenguatge PHP
Name[ca@valencia]=Implementació del llenguatge PHP
Name[cs]=Podpora jazyka PHP
Name[de]=Sprachunterstützung für PHP
Name[el]=Υποστήριξη γλώσσας PHP
Name[en_GB]=PHP Language Support
Name[es]=Implementación del lenguaje PHP
Name[fr]=Prise en charge du langage PHP
Name[gl]=Compatibilidade coa linguaxe PHP
Name[it]=Supporto al linguaggio PHP
Name[nb]=PHP språkstøtte
Name[nl]=Ondersteuning van PHP-taal
Name[pl]=Obsługa języka PHP
Name[pt]=Suporte da Linguagem PHP
Name[pt_BR]=Suporte à linguagem PHP
Name[sk]=Jazyková podpora PHP
Name[sl]=Podpora jeziku PHP
Name[sv]=PHP-språkstöd
Name[tr]=PHP Dili Desteği
Name[uk]=Підтримка мови PHP
Name[x-test]=xxPHP Language Supportxx
Name[zh_CN]=Php 语言支持
ServiceTypes=KDevelop/Plugin
Icon=application-x-php
X-KDE-Library=kdevphplanguagesupport
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Language=Php
X-KDevelop-Args=PHP
X-KDevelop-Interfaces=ILanguageSupport
X-KDevelop-SupportedMimeTypes=application/x-php
X-KDE-PluginInfo-Name=KDevPhpSupport
X-KDE-PluginInfo-Category=Language Support
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn
